/*This code imports the official tax tabulations, which are then processed using GPinter. 
The raw data is stored in fiscal-data/raw-data/TabRepNationaux20012022.xlsx. 
The data is then reorganized in gpinter-input.xlsx to be compatible with GPinter.
*/


global country fr

// Import tabulations
clear
forval y=2011/2022 {
preserve

import excel "$fiscal/gpinter/gpinter-input.xlsx", sheet("`y'") firstrow clear
    egen mean = mean(cond(thr == 0,average, .))
	renvars thr bracketavg / t a 
	drop country year popsize total average p
	gen year=`y'
	tempfile temp
	save `temp'
restore
append using `temp'
}

drop if mi(t)

// Merge with French population data
preserve
clear

wid, indicators(npopul) areas(FR)  year(2011/2022) ages(992) pop(i)
keep year value
ren value npop
tempfile temp
save `temp'
restore
merge m:1 year using `temp', nogen keep(matched)

sort year t n

gsort year -t
gen x=n/npop
by year: gen p=1-sum(x)

gen iso=upper("$country")

bys iso year (p): replace p=0 if _n==1
keep iso year p t a mean
order iso year p t a mean
sort iso year p t a mean

save "$fiscal/gpinter/gpinter-input.dta", replace
