library(magrittr)
library(haven)
library(plyr)
library(dplyr)
library(gpinter)
library(parallel)
library(doParallel)

work <- commandArgs(trailingOnly = TRUE)[1]
if (is.na(work)) {
  work <- path.expand("ADD PATH/fiscal/gpinter")
}

country <- "FR"

data_input <- read_dta(file.path(work, "gpinter-input.dta"))

gperc <- c(
  seq(0, 99000, 1000), seq(99100, 99900, 100),
  seq(99910, 99990, 10), seq(99991, 99999, 1)
)


merged <- data.frame()
for (y in unique(data_input$year)){
  df <- subset(data_input,year==y)
  dist <- thresholds_fit(p = df$p,
                         threshold=df$t,
                         fast = TRUE)
  tabulation <- as.data.frame(generate_tabulation(dist, gperc/1e5))
  tabulation$year <- y
  tabulation$country <- country
  tabulation %<>% transmute(
    country,year,
    p = fractile,
    thr = threshold,
    bracketavg = bracket_average,
    bracketshare = bracket_share,
    topsh = top_share,
    botsh = bottom_share
  )
  write_dta(tabulation, file.path(work, paste("gpinter-output-",y,".dta",sep="")))

  merged<-rbind(merged,tabulation)
}
write_dta(merged, file.path(work, paste("gpinter-output.dta",sep="")))


