/*This code imports the pre-tax DINA series from Bozio, A., Garbinti, B., Goupille-Lebret, J., Guillot, M., & Piketty, T. (2024). 
"Predistribution versus Redistribution: Evidence from France and the United States". American Economic Journal: Applied Economics, 16(2), 31-65 (BG3P, henceforth)
*/

global country fr

/* In this commented section the data series are imported, prepared for gpinter and gpinterized on WID.World

//Import average income from wid-world 

clear 
wid, indicators(anninc) pop(i) ages(992) area(FR) year(1970/2018)

ren country iso 
ren value average 

keep iso year  average 

tempfile macro_fr
save `macro_fr'


//Prepare BG3P series to be gpinterized (only deciles available)

use "$dina/dpercr_pretaxCN_equal.dta", clear

		
keep share_dperc dperc year 

merge m:1 year using `macro_fr', nogenerate

ren share_dperc bracketsh 
ren dperc p 

gen n = .1 if inrange(p,0,80)
replace n=0.05 if p==90
replace n=0.04 if p==95 
replace n=0.005 if p==99 
replace n=0.004 if p==995 
replace n=0.0009 if p==999 
replace n=0.0001 if p==9999

gen bracketavg = (bracketsh/(n))*average


replace p = p/100
replace p = p/10 if p>9
replace p = p/10 if p>9

gen country = "FR"
gen component = "sptinc992j"

// export gpinter-input for interpolation

levelsof year, local(years)
foreach l of local years  {
	
export excel "$work/gpinter/gpinter_input.xlsx" ///
if year == `l', sheet("`l'_sptinc992j", replace) first(var) keepcellfmt
}


/*Run gpinter on wid.world : https://wid.world/gpinter/ using "$work/gpinter/gpinter_input.xlsx as input.
Rename the output "gpinter-output-fr.xlsx" and save it in $work/gpinter
*/

*/

//Import the gpinter-output 

clear all
forvalues  t = 1970/2018  {
 foreach c in sptinc992j   {
	preserve
		import excel "$work/gpinter/gpinter-output-fr.xlsx", ///
			sheet("`c', FR, `t'") firstrow clear
			
		replace year = year[1] if mi(year)
		replace country = country[1] if mi(country)
		replace component = component[1] if mi(component)
		replace average = average[1] if mi(average)
		
		drop topavg average b

		tempfile temp
		save `temp'
	restore
	append using `temp', force
}	
 }

destring year, replace
rename thr t
rename topsh s
rename bracketavg a
rename component type
rename country iso
replace type = "pretax_inc" if type == "sptinc992j"


save "$work/gpinter/gpinter-output-fr.dta", replace
