/*This code extrapolates the series from BG3P based on the official fiscal data
*/

// EXTRAPOLATION PRE-TAX INCOME 2019-2022 BASED ON TAX TABULATIONS

// -----------------------------------------------------------
//Import average national income to recompute bracket averages 
// -----------------------------------------------------------

clear 
wid, indicators(anninc) pop(i) ages(992) area(FR) year(1970/2022)

ren country iso 
ren value anninc992i

keep iso year anninc992i

tempfile average
save `average'

// -----------------------------------------------------------
//Import fiscal income shares (gpinterized tabulations)
// -----------------------------------------------------------

use "$fiscal/gpinter/gpinter-output.dta", clear
keep year p topsh

ren topsh sfiinc992t

tempfile fiinc
save `fiinc'

// Get DINA shares up to 2018 from BG3P 

use "$work/gpinter/gpinter-output-fr.dta", clear

keep if type == "pretax_inc"

keep year s p type 

ren s sptinc992j 

merge 1:1 year p using `fiinc', nogen

sort year p 

// -----------------------------------------------------------
// Combine corrected tax unit fiscal income with pretax income
// -----------------------------------------------------------

// Estimate pre-tax/fiscal income ratios   


preserve 

keep if year == 2016

generate ptfiratio = sptinc992j/sfiinc992t

drop year 

tempfile ratio16
save `ratio16'

restore

merge m:m p using `ratio16', nogen

sort year p 

replace  sptinc992j = sfiinc992t*ptfiratio if year>2016

bys year : gen bracketshpre = sptinc992j[_n] - sptinc992j[_n+1]
replace bracketshpre = sptinc992j if p==.99999

keep year p sptinc992j bracketshpre type 

merge m:1 year using `average', nogen

gen n=0.01 if p<.99000
replace n=0.001 if inrange(p,.99000,.99800)
replace n=0.0001 if inrange(p,.99900,.99980)
replace n=0.00001 if inrange(p,.99990,.99999)

gen bracketavgpre = (bracketshpre/(n))*anninc992i


save "$work/dina-intermediary-fr.dta", replace

// Gpinterize the extrapolated series based on tax tabulations


ren anninc992i average

keep iso year sptinc992j p average bracketshpre bracketavgpre 
ren bracketshpre bracketsh
ren bracketavgpre bracketavg
ren sptinc992j topsh 
gen component = "pretax_inc"

keep if inrange(year, 2016, 2022)

levelsof year, local(years)
foreach l of local years  {
	
export excel "$work/gpinter/gpinter_input_20162022.xlsx" ///
if year == `l', sheet("`l'_sptinc992j", replace) first(var) keepcellfmt
}

// -------------------------------------------------------------------------------
//Run gpinter on wid.world : https://wid.world/gpinter/ using "$work/gpinter/gpinter-input-20162022.xlsx as input.
//Rename the output "gpinter-output-20162022.xlsx" and save it in $folder/work-data/gpinter
// --------------------------------------------------------------------------------


// -----------------------------------------------------------
//Import gpinter output for the years 2011-2016 
// -----------------------------------------------------------

clear all
forvalues  t = 2016/2022  {
 foreach c in pretax_inc  {
	preserve
		import excel "$work/gpinter/gpinter-output-20162022.xlsx", ///
			sheet("`c', `t'") firstrow clear
			
		replace year = year[1] if mi(year)
		replace component = component[1] if mi(component)
		replace average = average[1] if mi(average)
		
		drop average 

		tempfile temp
		save `temp'
	restore
	append using `temp', force
}	
 }

destring year, replace
rename thr t
rename topsh s
rename bracketavg a
rename component type
gen iso="FR"


preserve 

use "$work/gpinter/gpinter-output-fr.dta", clear

keep if inrange(year, 1970, 2015)

tempfile orig
save `orig'

restore 

append using `orig' 

sort year type p

save "$work/gpinter/gpinter-output-fr-total.dta", replace

// ----------------------------------------------------------------------------
/*Extrapolation 2023: 2022 shares with 2023 aggregates: 
  we keep the 2022 shares and adjust the bracket averages to the 2023 macro aggregates */
// -----------------------------------------------------------------------------

clear 
wid, indicators(anninc) pop(i) ages(992) area(FR) year(2023)

ren country iso 
ren value anninc992i

keep iso year anninc992i
replace year = 2022 if year == 2023


tempfile average23

save `average23'


use "$work/gpinter-output-fr-total.dta", clear

keep if year == 2022
merge m:m year using `average23', nogen

drop a t 

gen n=0.01 if p<.99000
replace n=0.001 if inrange(p,.99000,.99800)
replace n=0.0001 if inrange(p,.99900,.99980)
replace n=0.00001 if inrange(p,.99990,.99999)


bys type year: gen bracketavg = (bracketsh/(n))*anninc992i

//Prepare for gpinter

ren iso country 
ren s topsh 
ren anninc992i average 
ren type component 
drop n 

replace year = 2023 if year == 2022

levelsof component, local(components)
foreach t of local components  {
	
export excel "$work/gpinter/gpinter_input_2023.xlsx" ///
if component == "`t'", sheet("2023_`t'", replace) first(var) keepcellfmt
}
// ----------------------------------------------------------------------------
//Run gpinter on wid.world : https://wid.world/gpinter/ using "$work/gpinter/gpinter-input-2023 as input.
//Rename the output "gpinter-output-2023" and save it in $folder/work-data/gpinter
// ----------------------------------------------------------------------------

// ----------------------------------------------------------------------------
//Import gpinter output
// ----------------------------------------------------------------------------


clear

 foreach c in pretax_inc   {
	preserve
		import excel "$work/gpinter/gpinter-output-2023.xlsx", ///
			sheet("`c', FR, 2023") firstrow clear
			
		replace year = year[1] if mi(year)
		replace component = component[1] if mi(component)
		replace country = country[1] if mi(country)
		
		drop average b

		tempfile temp
		save `temp'
	restore
	append using `temp', force
}	


destring year, replace
rename thr t
rename topsh s
rename bracketavg a
rename component type
rename country iso 

append using "$work/gpinter/gpinter-output-fr-total.dta"

sort year p type

drop bracketsh 

replace p = p*100*1000
gen unit = "coup" 

keep if inrange(year, 1980, 2023)

gen n=0.01 if p<99000
replace n=0.001 if inrange(p,99000,99800)
replace n=0.0001 if inrange(p,99900,99980)
replace n=0.00001 if inrange(p,99990,99999)

rename t thr
rename s topsh
rename a bracketavg

// Normalise 
gen x = bracketavg*n
bys iso year type: egen average=sum(x)
drop x
replace bracketavg = bracketavg/average
replace thr = thr/average
keep year iso type unit p thr bracketavg topsh


save "$work/dina-fr-final.dta", replace



